@@ -29,6 +29,13 @@ def mainArgs() -> Namespace:
         type=str,
         default="bus_factor.json",
     )
+    parser.add_argument(
+        "-b",
+        "--bucket",
+        help="Bucket containing the number of days between computed bus factor values. DEFAULT: 1",
+        type=int,
+        default=1,
+    )
     parser.add_argument(
         "-v",
         "--version",
